Learn R Programming

repo.data (version 0.1.5)

base_help_pages_not_linked: Help pages without links

Description

Help pages without links to other help pages. This makes harder to navigate to related help pages.

Usage

base_help_pages_not_linked()

Arguments

Value

A data.frame with two columns: Package and Source. NA if not able to collect the data from CRAN.

See Also

Other functions related to BASE help pages: base_help_cliques(), base_help_pages_wo_links()

Examples

Run this code
# \donttest{
bhnl <- base_help_pages_not_linked()
head(bhnl)
# }

Run the code above in your browser using DataLab