Learn R Programming

repo.data (version 0.1.5)

base_pages_links: Links between help pages by page

Description

Explore the relationship between base R packages and other help pages. If the target help page is ambiguous it is omitted.

Usage

base_pages_links(packages = NULL)

Value

A data.frame with 6 columns: from_pkg, from_Rd, to_pkg, to_Rd, n (Number of links). NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.

See Also

Other links from R: base_links(), base_pkges_links(), base_targets_links()

Examples

Run this code
# \donttest{
bpl <- base_pages_links()
head(bpl)
# }

Run the code above in your browser using DataLab