Learn R Programming

repo.data (version 0.1.5)

base_pkges_links: Links between help pages by package

Description

Explore the relationship between base R packages and other packages. If the target package is ambiguous it is omitted.

Usage

base_pkges_links(packages = NULL)

Value

A data.frame with 6 columns: from_pkg, to_pkg, n (Number of links). NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.

See Also

Other links from R: base_links(), base_pages_links(), base_targets_links()

Examples

Run this code
# \donttest{
bpkl <- base_pkges_links()
head(bpkl)
# }

Run the code above in your browser using DataLab