Learn R Programming

repo.data (version 0.1.5)

base_targets_links: Links between help pages by target

Description

Explore the relationship between base R packages and other help pages by the target they use.

Usage

base_targets_links(packages = NULL)

Value

A data.frame with 6 columns: from_pkg, from_Rd, to_pkg, to_target, to_Rd, n (Number of links). NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.

See Also

Other links from R: base_links(), base_pages_links(), base_pkges_links()

Examples

Run this code
# \donttest{
btl <- base_targets_links()
head(btl)
# }

Run the code above in your browser using DataLab