Learn R Programming

repo.data (version 0.1.5)

cran_help_pages_not_linked: Help pages without links

Description

Help pages without links to other help pages. This makes harder to navigate to related help pages.

Usage

cran_help_pages_not_linked(packages = NULL)

Value

A data.frame with two columns: Package and Source NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.

See Also

Other functions related to CRAN help pages: cran_help_cliques(), cran_help_pages_wo_links()

Examples

Run this code
# \donttest{
ap <- available.packages()
if (NROW(ap)) {
    a_package <- rownames(ap)[startsWith(rownames(ap), "A")][1]
    chnl <- cran_help_pages_not_linked(a_package)
    head(chnl)
}
# }

Run the code above in your browser using DataLab