powered by
Explore the relationship between CRAN packages and other packages. If the target package is ambiguous it is omitted.
cran_pkges_links(packages = NULL)
A data.frame with 6 columns: from_pkg, to_pkg, n (Number of links). NA if not able to collect the data from CRAN.
NA
A vector with packages or NULL for all packages.
NULL
Other links from CRAN: cran_links(), cran_pages_links(), cran_targets_links()
cran_links()
cran_pages_links()
cran_targets_links()
# \donttest{ cpkl <- cran_pkges_links() head(cpkl) # }
Run the code above in your browser using DataLab