Learn R Programming

repo.data (version 0.1.5)

cran_snapshot: Check CRAN package state on any given date

Description

Given the available information which packages were on CRAN on a given date?

Usage

cran_snapshot(date)

Value

The data.frame with the packages and versions at a given date. NA if not able to collect the data from CRAN.

Arguments

date

The date you want to check.

See Also

Other utilities: cran_date(), cran_doom(), duplicated_alias(), package_date(), package_repos(), repos_dependencies(), update_dependencies()

Examples

Run this code
# \donttest{
cs <- cran_snapshot(Sys.Date() -2 )
head(cs)
# }

Run the code above in your browser using DataLab