Learn R Programming

repo.data (version 0.1.5)

repo.data-package: repo.data: R Repository Data

Description

Retrieve metadata about packages from repositories to explore package dependencies, links between help pages, aliases, package availability on a given date, and other repository dependent outcome. This metadata can be used to help package maintainers and users to navigate changes on dependencies and with reproducibility.

Arguments

Author

Maintainer: Lluís Revilla Sancho lluis.revilla@gmail.com (ORCID) [copyright holder]

See Also