Learn R Programming

repo.data (version 0.1.5)

repos_dependencies: Tidy dependencies

Description

Extract the packages dependencies, name of the dependency, operator and version for each type and package of current repositories (getOptions("repos")).

Usage

repos_dependencies(packages = NULL, which = "all")

Value

A data.frame with 5 columns: the name of the dependency, the operator (op), the version it depends the type of dependency and the package. NA if not able to collect the data from CRAN.

Arguments

packages

a character vector of package names.

which

a character vector listing the types of dependencies, a subset of c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances"). Character string "all" is shorthand for that vector, character string "most" for the same vector without "Enhances", character string "strong" (default) for the first three elements of that vector.

See Also

Other utilities: cran_date(), cran_doom(), cran_snapshot(), duplicated_alias(), package_date(), package_repos(), update_dependencies()

Examples

Run this code
rd <- repos_dependencies("BaseSet")
head(rd)

Run the code above in your browser using DataLab