Learn R Programming

repo.data (version 0.1.5)

base_help_cliques: Help pages with cliques

Description

Some help pages have links to and from but they are closed networks.

Usage

base_help_cliques()

Arguments

Value

Return a data.frame of help pages not connected to the network of help pages. NA if not able to collect the data from CRAN.

Details

Requires igraph

See Also

Other functions related to BASE help pages: base_help_pages_not_linked(), base_help_pages_wo_links()

Examples

Run this code
# \donttest{
if (requireNamespace("igraph", quietly = TRUE)) {
    base_help_cliques()
}
# }

Run the code above in your browser using DataLab