powered by
Some help pages have links to and from but they are closed networks.
base_help_cliques()
Return a data.frame of help pages not connected to the network of help pages. NA if not able to collect the data from CRAN.
NA
Requires igraph
Other functions related to BASE help pages: base_help_pages_not_linked(), base_help_pages_wo_links()
base_help_pages_not_linked()
base_help_pages_wo_links()
# \donttest{ if (requireNamespace("igraph", quietly = TRUE)) { base_help_cliques() } # }
Run the code above in your browser using DataLab