powered by
Explore the relationship between base R packages and other help pages. If the target help page is ambiguous it is omitted.
base_pages_links(packages = NULL)
A data.frame with 6 columns: from_pkg, from_Rd, to_pkg, to_Rd, n (Number of links). NA if not able to collect the data from CRAN.
NA
A vector with packages or NULL for all packages.
NULL
Other links from R: base_links(), base_pkges_links(), base_targets_links()
base_links()
base_pkges_links()
base_targets_links()
# \donttest{ bpl <- base_pages_links() head(bpl) # }
Run the code above in your browser using DataLab