powered by
Explore the relationship between base R packages and other packages. If the target package is ambiguous it is omitted.
base_pkges_links(packages = NULL)
A data.frame with 6 columns: from_pkg, to_pkg, n (Number of links). NA if not able to collect the data from CRAN.
NA
A vector with packages or NULL for all packages.
NULL
Other links from R: base_links(), base_pages_links(), base_targets_links()
base_links()
base_pages_links()
base_targets_links()
# \donttest{ bpkl <- base_pkges_links() head(bpkl) # }
Run the code above in your browser using DataLab