Learn R Programming

repo.data (version 0.1.5)

bioc_cran_archived: Bioconductor packages using CRAN archived packages

Description

Checks on the 4 Bioconductor repositories which packages depend on a archived package.

Usage

bioc_cran_archived(which = "strong")

Value

A data.frame with the name of the Bioconductor packages depending on archived packages (on Archived column) and the number of missing packages (n). NA if not able to collect the data.

Arguments

which

a character vector listing the types of dependencies, a subset of c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances"). Character string "all" is shorthand for that vector, character string "most" for the same vector without "Enhances", character string "strong" (default) for the first three elements of that vector.

See Also

For CRAN's data source: tools::CRAN_package_db()

Examples

Run this code
bca <- bioc_cran_archived()
head(bca)

Run the code above in your browser using DataLab