Learn R Programming

repo.data (version 0.1.5)

cran_actions: Look at the CRAN actions db

Description

CRAN tracks movements of packages and the actions used (for example to report the number of manual actions taken by the volunteers).

Usage

cran_actions(packages = NULL, silent = FALSE)

Value

A data.frame with Date, Time, User, Action, Package and Version columns. NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.