powered by
CRAN tracks movements of packages and the actions used (for example to report the number of manual actions taken by the volunteers).
cran_actions(packages = NULL, silent = FALSE)
A data.frame with Date, Time, User, Action, Package and Version columns. NA if not able to collect the data from CRAN.
NA
A vector with packages or NULL for all packages.
NULL