Some help pages have links to other pages and they might be linked from others
but they are closed network: there is no link that leads to different help pages.
Usage
cran_help_cliques(packages = NULL)
Value
Return a data.frame of help pages not connected to the network of help pages.
Or NULL if nothing are found.
NA if not able to collect the data from CRAN.
Arguments
packages
A vector with packages or NULL for all packages.
Details
Requires igraph
See Also
Other functions related to CRAN help pages:
cran_help_pages_not_linked(),
cran_help_pages_wo_links()