Learn R Programming

repo.data (version 0.1.5)

cran_history: Check package history on CRAN

Description

It uses available information to provide the most accurate information of CRAN at any given time.

Usage

cran_history(packages = NULL)

Value

A data.frame with the information to recreate CRAN at any point before today. NA if not able to collect the data from CRAN.

Arguments

packages

A vector with packages or NULL for all packages.

Details

Several sources are used: CRAN's database to check packages files and versions, CRAN's volunteers actions for when packages are archived or removed and CRAN's comments to fill in the gaps.

See Also

cran_archive(), cran_actions(), cran_comments().

Other meta info from CRAN: cran_alias(), cran_archive(), cran_comments(), cran_links()

Examples

Run this code
cran_history

Run the code above in your browser using DataLab