Learn R Programming

repo.data (version 0.1.5)

cran_maintainers: Tidy information about maintainers

Description

Make more accessible information about maintainers. Extracts and makes comparable some dates. It also provides the user name used and cleans the names of the maintainer of extra quotes.

Usage

cran_maintainers()

Arguments

Value

A data.frame with one row per package and 11 columns. The package name, Maintainer field, user maintainer manual date, packaged date, published date, name of maintainer used, email used, direction and domain. NA if not able to collect the data from CRAN.

Details

User is what the machine building the package reported. This might indicate some collaboration, repackaging or simply nothing as it can be hidden/modified. The name, email and user might help identify similar named people (or confuse between maintainers)

See Also

The raw source of the data is: CRAN_authors_db()

Examples

Run this code
maintainers <- cran_maintainers()
head(maintainers)

Run the code above in your browser using DataLab