A data.frame with one row per package and 11 columns.
The package name, Maintainer field, user maintainer manual date, packaged
date, published date, name of maintainer used, email used, direction and domain.
NA if not able to collect the data from CRAN.