powered by
Given the available information which packages were on CRAN on a given date?
cran_snapshot(date)
The data.frame with the packages and versions at a given date. NA if not able to collect the data from CRAN.
NA
The date you want to check.
Other utilities: cran_date(), cran_doom(), duplicated_alias(), package_date(), package_repos(), repos_dependencies(), update_dependencies()
cran_date()
cran_doom()
duplicated_alias()
package_date()
package_repos()
repos_dependencies()
update_dependencies()
# \donttest{ cs <- cran_snapshot(Sys.Date() -2 ) head(cs) # }
Run the code above in your browser using DataLab