package_repos: Package dependencies to repositories
Description
Explore the relationships between packages and repositories available.
Usage
package_repos(packages = NULL, repos = getOption("repos"), which = "all")
Value
A data.frame with one line per package and at least one column per
repository. It also has a column for Other repositories (Additional_repositories,
or missing repositories), and the total number of dependencies and total
number of repositories used.
NA if not able to collect the data from repositories.
Arguments
packages
a character vector of package names.
repos
Repositories and their names are taken from getOptions("repos").
which
a character vector listing the types of
dependencies, a subset of
c("Depends", "Imports", "LinkingTo", "Suggests", "Enhances").
Character string "all" is shorthand for that vector,
character string "most" for the same vector without
"Enhances",
character string "strong" (default) for the first three
elements of that vector.
See Also
Other utilities:
cran_date(),
cran_doom(),
cran_snapshot(),
duplicated_alias(),
package_date(),
repos_dependencies(),
update_dependencies()